diff --git a/Tools/APM2_2560_bootloader/Makefile b/Tools/APM2_2560_bootloader/Makefile
index 0eb7415da0..d524428ec0 100644
--- a/Tools/APM2_2560_bootloader/Makefile
+++ b/Tools/APM2_2560_bootloader/Makefile
@@ -91,7 +91,7 @@ DEBUG = dwarf-2
# List any extra directories to look for include files here.
-# Each directory must be seperated by a space.
+# Each directory must be separated by a space.
# Use forward slashes for directory separators.
# For a directory that has spaces, enclose it in quotes.
EXTRAINCDIRS =
diff --git a/Tools/ArduPPM/ATMega328p/manual.txt b/Tools/ArduPPM/ATMega328p/manual.txt
index aa8454ff36..aad346ec26 100644
--- a/Tools/ArduPPM/ATMega328p/manual.txt
+++ b/Tools/ArduPPM/ATMega328p/manual.txt
@@ -20,7 +20,7 @@ Emphasis has been put on code simplicity and reliability.
Code has not yet been massively tested in the field.
-Nevertheless extensive tests have been done in the lab with a limited set of different receivers, and a limited number of users did report very sucessfull results.
+Nevertheless extensive tests have been done in the lab with a limited set of different receivers, and a limited number of users did report very successful results.
Carefully check that your radio is working perfectly before you fly.
diff --git a/Tools/ArduPPM/ATMega32U2/Bootloaders/arduino-usbdfu/makefile b/Tools/ArduPPM/ATMega32U2/Bootloaders/arduino-usbdfu/makefile
index 4567d79d5b..0bd1b2c916 100644
--- a/Tools/ArduPPM/ATMega32U2/Bootloaders/arduino-usbdfu/makefile
+++ b/Tools/ArduPPM/ATMega32U2/Bootloaders/arduino-usbdfu/makefile
@@ -177,7 +177,7 @@ DEBUG = dwarf-2
# List any extra directories to look for include files here.
-# Each directory must be seperated by a space.
+# Each directory must be separated by a space.
# Use forward slashes for directory separators.
# For a directory that has spaces, enclose it in quotes.
EXTRAINCDIRS = $(LUFA_PATH)/
@@ -316,7 +316,7 @@ MATH_LIB = -lm
# List any extra directories to look for libraries here.
-# Each directory must be seperated by a space.
+# Each directory must be separated by a space.
# Use forward slashes for directory separators.
# For a directory that has spaces, enclose it in quotes.
EXTRALIBDIRS =
diff --git a/Tools/ArduPPM/ATMega32U2/LUFA/Doxygen.conf b/Tools/ArduPPM/ATMega32U2/LUFA/Doxygen.conf
index d69b12d190..c3bf87ffb1 100644
--- a/Tools/ArduPPM/ATMega32U2/LUFA/Doxygen.conf
+++ b/Tools/ArduPPM/ATMega32U2/LUFA/Doxygen.conf
@@ -291,7 +291,7 @@ TYPEDEF_HIDES_STRUCT = YES
# causing a significant performance penality.
# If the system has enough physical memory increasing the cache will improve the
# performance by keeping more symbols in memory. Note that the value works on
-# a logarithmic scale so increasing the size by one will rougly double the
+# a logarithmic scale so increasing the size by one will roughly double the
# memory usage. The cache size is given by this formula:
# 2^(16+SYMBOL_CACHE_SIZE). The valid range is 0..9, the default is 0,
# corresponding to a cache size of 2^16 = 65536 symbols
diff --git a/Tools/ArduPPM/ATMega32U2/LUFA/ManPages/BuildingLinkableLibraries.txt b/Tools/ArduPPM/ATMega32U2/LUFA/ManPages/BuildingLinkableLibraries.txt
index 70919c0a23..b58966d82f 100644
--- a/Tools/ArduPPM/ATMega32U2/LUFA/ManPages/BuildingLinkableLibraries.txt
+++ b/Tools/ArduPPM/ATMega32U2/LUFA/ManPages/BuildingLinkableLibraries.txt
@@ -6,7 +6,7 @@
/** \page Page_BuildLibrary Building as a Linkable Library
*
- * The LUFA library can be built as a proper linkable library (with the extention .a) under AVR-GCC, so that
+ * The LUFA library can be built as a proper linkable library (with the extension .a) under AVR-GCC, so that
* the library does not need to be recompiled with each revision of a user project. Instructions for creating
* a library from a given source tree can be found in the AVR-GCC user manual included in the WinAVR install
* /Docs/ directory.
diff --git a/Tools/ArduPPM/ATMega32U2/LUFA/ManPages/ChangeLog.txt b/Tools/ArduPPM/ATMega32U2/LUFA/ManPages/ChangeLog.txt
index 6ea4dfb760..6d4f74f420 100644
--- a/Tools/ArduPPM/ATMega32U2/LUFA/ManPages/ChangeLog.txt
+++ b/Tools/ArduPPM/ATMega32U2/LUFA/ManPages/ChangeLog.txt
@@ -436,7 +436,7 @@
* of device configurations can be defined statically
* - Removed VBUS events, as they are already exposed to the user application via the regular device connection and disconnection events
* - Renamed and altered existing events to properly separate out Host and Device mode events
- * - All demos switched over from GNU99 standards mode to C99 standards mode, to reduce the dependancies on GCC-only language extensions
+ * - All demos switched over from GNU99 standards mode to C99 standards mode, to reduce the dependencies on GCC-only language extensions
*
* Fixed:
* - Changed bootloaders to use FLASHEND rather than the existence of RAMPZ to determine if far FLASH pointers are needed to fix
@@ -978,7 +978,7 @@
* - AVR_HOST_GetDeviceConfigDescriptor routine no longer modifies ConfigSizePtr if a valid buffer
* pointer is passed
* - Added ALLOCABLE_BYTES to DynAlloc, and added code to make the size of key storage variables
- * dependant on size of memory parameters passed in via the user project's makefile
+ * dependent on size of memory parameters passed in via the user project's makefile
* - Fixed incorrect device reset routine being called in USBTask
* - Devices which do not connect within the standard 300mS are now supported
* - Removed incorrect ATTR_PURE from Scheduler_SetTaskMode(), which was preventing tasks from being
diff --git a/Tools/ArduPPM/ATMega32U2/LUFA/Scheduler/Scheduler.h b/Tools/ArduPPM/ATMega32U2/LUFA/Scheduler/Scheduler.h
index 673a933f8e..dd46a5c678 100644
--- a/Tools/ArduPPM/ATMega32U2/LUFA/Scheduler/Scheduler.h
+++ b/Tools/ArduPPM/ATMega32U2/LUFA/Scheduler/Scheduler.h
@@ -197,7 +197,7 @@
/* Inline Functions: */
/** Resets the delay counter value to the current tick count. This should be called to reset the period
- * for a delay in a task which is dependant on the current tick value.
+ * for a delay in a task which is dependent on the current tick value.
*
* \param[out] DelayCounter Counter which is storing the starting tick count for a given delay.
*/
diff --git a/Tools/ArduPPM/ATMega32U2/Projects/arduino-usbserial/makefile b/Tools/ArduPPM/ATMega32U2/Projects/arduino-usbserial/makefile
index 8e7d3aa9f8..ef5d5fdc9a 100644
--- a/Tools/ArduPPM/ATMega32U2/Projects/arduino-usbserial/makefile
+++ b/Tools/ArduPPM/ATMega32U2/Projects/arduino-usbserial/makefile
@@ -191,7 +191,7 @@ DEBUG = dwarf-2
# List any extra directories to look for include files here.
-# Each directory must be seperated by a space.
+# Each directory must be separated by a space.
# Use forward slashes for directory separators.
# For a directory that has spaces, enclose it in quotes.
EXTRAINCDIRS = $(LUFA_PATH)/
@@ -332,7 +332,7 @@ MATH_LIB = -lm
# List any extra directories to look for libraries here.
-# Each directory must be seperated by a space.
+# Each directory must be separated by a space.
# Use forward slashes for directory separators.
# For a directory that has spaces, enclose it in quotes.
EXTRALIBDIRS =
diff --git a/Tools/ArduPPM/Libraries/PPM_Encoder.h b/Tools/ArduPPM/Libraries/PPM_Encoder.h
index 46e0b44b5b..776290765a 100644
--- a/Tools/ArduPPM/Libraries/PPM_Encoder.h
+++ b/Tools/ArduPPM/Libraries/PPM_Encoder.h
@@ -45,7 +45,7 @@
// V2.2.3 - Implemented 0.5us cut filter to remove servo input capture jitter.
// 04-08-2011
-// V2.2.4 - Implemented PPM passtrough funtion.
+// V2.2.4 - Implemented PPM passtrough function.
// Shorting channel 2&3 enabled ppm passtrough on channel 1.
// 04-08-2011
diff --git a/Tools/ArduPPM/Libraries/changelog_v3.txt b/Tools/ArduPPM/Libraries/changelog_v3.txt
index 3ab3407a87..dff55e2a4c 100644
--- a/Tools/ArduPPM/Libraries/changelog_v3.txt
+++ b/Tools/ArduPPM/Libraries/changelog_v3.txt
@@ -15,7 +15,7 @@
// V2.2.3 - Implemented 0.5us cut filter to remove servo input capture jitter.
// 04-08-2011
-// V2.2.4 - Implemented PPM passtrough funtion.
+// V2.2.4 - Implemented PPM passtrough function.
// Shorting channel 2&3 enabled ppm passtrough on channel 1.
// 04-08-2011
diff --git a/Tools/ArduPPM/WorkBasket/Experimental/PPM_Encoder.h b/Tools/ArduPPM/WorkBasket/Experimental/PPM_Encoder.h
index 37125efb3d..09bc74bfd0 100644
--- a/Tools/ArduPPM/WorkBasket/Experimental/PPM_Encoder.h
+++ b/Tools/ArduPPM/WorkBasket/Experimental/PPM_Encoder.h
@@ -17,7 +17,7 @@
// V2.2.3 - Implemented 0.5us cut filter to remove servo input capture jitter.
// 04-08-2011
-// V2.2.4 - Implemented PPM passtrough funtion.
+// V2.2.4 - Implemented PPM passtrough function.
// Shorting channel 2&3 enabled ppm passtrough on channel 1.
// 04-08-2011
@@ -842,7 +842,7 @@ void ppm_encoder_init( void )
uint16_t input_channel_count[ SERVO_CHANNELS ];
uint8_t input_current; // Input pin level mask
uint8_t input_previous; // Input pin level mask
- uint8_t input_int_mask; // Active input pin interupt mask
+ uint8_t input_int_mask; // Active input pin interrupt mask
INPUT_ACTIVE_CHANNEL_CHECK:
@@ -897,7 +897,7 @@ void ppm_encoder_init( void )
// Set active channel in servo_input_connected[..]
servo_input_connected[ (input_channel << 1) + 1 ] = true;
- // Set interupt pin mask for active channel
+ // Set interrupt pin mask for active channel
input_int_mask |= 1 << input_channel;
}
diff --git a/Tools/ArduPPM/WorkBasket/readme.txt b/Tools/ArduPPM/WorkBasket/readme.txt
index 9a03b12c96..08ed7712e5 100644
--- a/Tools/ArduPPM/WorkBasket/readme.txt
+++ b/Tools/ArduPPM/WorkBasket/readme.txt
@@ -1,5 +1,5 @@
-The ArduPPM "Workbasket" is a source of code or tools usefull for ppm encoder projects.
+The ArduPPM "Workbasket" is a source of code or tools useful for ppm encoder projects.
It is recommanded to delete no more needed stuff when integration in the ArduPPM code has been done to keep the repository size smaller.
diff --git a/Tools/ArduPPM/WorkBasket/spektrum_to_ppm_encoder/spektrum_to_ppm_encoder.pde b/Tools/ArduPPM/WorkBasket/spektrum_to_ppm_encoder/spektrum_to_ppm_encoder.pde
index 26ae6eb16a..be56d447a1 100644
--- a/Tools/ArduPPM/WorkBasket/spektrum_to_ppm_encoder/spektrum_to_ppm_encoder.pde
+++ b/Tools/ArduPPM/WorkBasket/spektrum_to_ppm_encoder/spektrum_to_ppm_encoder.pde
@@ -32,7 +32,7 @@
#define baud_setting 16 // See page 231 of the data sheet
- // Comment - this software rearranges the channel order from the tranmsitter to match APM useage
+ // Comment - this software rearranges the channel order from the tranmsitter to match APM usage
// Ch1 = Aileron = Spectrum Ch2
// Ch2 = Elevator = Spectrum Ch3
// Ch3 = Throttle = Spectrum Ch1
@@ -184,7 +184,7 @@ ISR(TIMER1_COMPA_vect) {
falling_edge = TRUE;
ch_index++;
} else {
- // set timer top to max to minimize interupt execution when not sending a frame
+ // set timer top to max to minimize interrupt execution when not sending a frame
OCR1A = 0xffff;
}
} else {
@@ -193,7 +193,7 @@ ISR(TIMER1_COMPA_vect) {
OCR1A = 4800; //16 * 300, 300 usec negative going pulse width;
falling_edge = FALSE;
} else {
- // set timer top to max to minimize interupt execution when not sending a frame
+ // set timer top to max to minimize interrupt execution when not sending a frame
OCR1A = 0xffff;
}
}
diff --git a/Tools/Linux_HAL_Essentials/RCInput_UART/pic_firmware.asm b/Tools/Linux_HAL_Essentials/RCInput_UART/pic_firmware.asm
index 28b6836d42..f60b9c2096 100644
--- a/Tools/Linux_HAL_Essentials/RCInput_UART/pic_firmware.asm
+++ b/Tools/Linux_HAL_Essentials/RCInput_UART/pic_firmware.asm
@@ -34,7 +34,7 @@
cblock 0x020
; input_value, input_rise and input_mirror
- ; are at the bank's begining to make easy
+ ; are at the bank's beginning to make easy
; the exchange of data between them.
input_value:(INPUT_NUM * 2)
input_previous
@@ -364,7 +364,7 @@ ClearBank:
; clears the gpr bank pointed by w plus irp,
; but preserves the common 16 bytes.
- ; ensure the begining of the bank
+ ; ensure the beginning of the bank
andlw b'10100000'
movwf FSR
movlw .80
diff --git a/Tools/LogAnalyzer/LogAnalyzer.py b/Tools/LogAnalyzer/LogAnalyzer.py
index edf58ad6e9..1eea7b0a40 100755
--- a/Tools/LogAnalyzer/LogAnalyzer.py
+++ b/Tools/LogAnalyzer/LogAnalyzer.py
@@ -189,12 +189,12 @@ class TestSuite(object):
print >>xml, " " + escape(test.name) + ""
print >>xml, " FAIL"
print >>xml, " " + escape(test.result.statusMessage) + ""
- print >>xml, " (test data will be embeded here at some point)"
+ print >>xml, " (test data will be embedded here at some point)"
elif test.result.status == TestResult.StatusType.WARN:
print >>xml, " " + escape(test.name) + ""
print >>xml, " WARN"
print >>xml, " " + escape(test.result.statusMessage) + ""
- print >>xml, " (test data will be embeded here at some point)"
+ print >>xml, " (test data will be embedded here at some point)"
elif test.result.status == TestResult.StatusType.NA:
print >>xml, " " + escape(test.name) + ""
print >>xml, " NA"
diff --git a/Tools/LogAnalyzer/example_output.xml b/Tools/LogAnalyzer/example_output.xml
index 101f5688d3..fed131a0af 100644
--- a/Tools/LogAnalyzer/example_output.xml
+++ b/Tools/LogAnalyzer/example_output.xml
@@ -313,13 +313,13 @@
Event/Failsafe
FAIL
ERR found: GPS
- (test data will be embeded here at some point)
+ (test data will be embedded here at some point)
GPS
WARN
Min satellites: 6, Max HDop: 4.68
- (test data will be embeded here at some point)
+ (test data will be embedded here at some point)
Parameters
@@ -330,7 +330,7 @@
PM
FAIL
14 slow loop lines found, max 18.56% on line 2983
- (test data will be embeded here at some point)
+ (test data will be embedded here at some point)
Pitch/Roll
diff --git a/Tools/SerialProxy/SerialProxy/Form1.cs b/Tools/SerialProxy/SerialProxy/Form1.cs
index 65a1b131f0..79965072fa 100644
--- a/Tools/SerialProxy/SerialProxy/Form1.cs
+++ b/Tools/SerialProxy/SerialProxy/Form1.cs
@@ -47,7 +47,7 @@ namespace SerialProxy
try
{
comPort.PortName = Comports.Text.ToString();
- comPort.DtrEnable = false; // dont reset yet
+ comPort.DtrEnable = false; // don't reset yet
comPort.Open();
StatusCom.Text = "Com Connected";
ConnectComPort.Text = "Disconnect";
diff --git a/Tools/autotest/aircraft/Rascal/README.Rascal b/Tools/autotest/aircraft/Rascal/README.Rascal
index d6c7c6ac25..e080fb9b82 100644
--- a/Tools/autotest/aircraft/Rascal/README.Rascal
+++ b/Tools/autotest/aircraft/Rascal/README.Rascal
@@ -135,7 +135,7 @@ tires.
rudder which is connected to a steerable tail wheel. Use brakes only
for positive, precision ground control when necessary.
-(3) Taxi upwind with stick back; downwind with stick foreward. When
+(3) Taxi upwind with stick back; downwind with stick forward. When
ground winds are in excess of 15 M.P.H., turn into wind using ailerons
in direction of turn; apply ailerons away from the turn when turning
downwind. This procedure helps to prevent the wind "picking up" a
diff --git a/Tools/autotest/pysim/fdpexpect.py b/Tools/autotest/pysim/fdpexpect.py
index 0ece98e6b9..2f583e6122 100644
--- a/Tools/autotest/pysim/fdpexpect.py
+++ b/Tools/autotest/pysim/fdpexpect.py
@@ -1,5 +1,5 @@
"""This is like pexpect, but will work on any file descriptor that you pass it.
-So you are reponsible for opening and close the file descriptor.
+So you are responsible for opening and close the file descriptor.
$Id: fdpexpect.py 505 2007-12-26 21:33:50Z noah $
"""
diff --git a/Tools/autotest/pysim/util.py b/Tools/autotest/pysim/util.py
index 6b6a4edbe5..03ab42452e 100644
--- a/Tools/autotest/pysim/util.py
+++ b/Tools/autotest/pysim/util.py
@@ -422,7 +422,7 @@ def apparent_wind(wind_sp, obj_speed, alpha):
# (let's assume it's low, .e.g., 0.2), p : density of air (assume about 1
# kg/m^3, the density just over 1500m elevation), v : relative speed of wind
# (to the body), a : area acted on (this is captured by the cross_section
-# paramter).
+# parameter).
#
# So then we have
# F(a) = 0.2 * 1/2 * v^2 * cross_section = 0.1 * v^2 * cross_section
diff --git a/Tools/autotest/sim_vehicle.py b/Tools/autotest/sim_vehicle.py
index 6a480c410d..ea0ca57d75 100755
--- a/Tools/autotest/sim_vehicle.py
+++ b/Tools/autotest/sim_vehicle.py
@@ -599,7 +599,7 @@ def start_mavproxy(opts, stuff):
if opts.mavproxy_args:
cmd.extend(opts.mavproxy_args.split(" ")) # this could be a lot better..
- # compatability pass-through parameters (for those that don't want
+ # compatibility pass-through parameters (for those that don't want
# to use -C :-)
for out in opts.out:
cmd.extend(['--out', out])
diff --git a/Tools/autotest/web-firmware/index.html b/Tools/autotest/web-firmware/index.html
index 3881b34ade..fc0b1f9292 100644
--- a/Tools/autotest/web-firmware/index.html
+++ b/Tools/autotest/web-firmware/index.html
@@ -171,8 +171,8 @@ python px_uploader.py --port /dev/ttyACM0 px4fmu.px4
After starting the script, press the reset button on your PX4FMU to
make it enter bootloader mode.
-Building the firmware youself
-To build the firmware youself please see the ArduPilot development site.
+Building the firmware yourself
+To build the firmware yourself please see the ArduPilot development site.
diff --git a/Tools/APM2_2560_bootloader/stk500boot.c b/Tools/APM2_2560_bootloader/stk500boot.c
index 5f6276a989..6eb43351f0 100644
--- a/Tools/APM2_2560_bootloader/stk500boot.c
+++ b/Tools/APM2_2560_bootloader/stk500boot.c
@@ -656,9 +656,9 @@ int main(void)
if (exPointCntr == 3)
{
RunMonitor();
- exPointCntr = 0; // reset back to zero so we dont get in an endless loop
+ exPointCntr = 0; // reset back to zero so we don't get in an endless loop
isLeave = 1;
- msgParseState = 99; //* we dont want it do anything
+ msgParseState = 99; //* we don't want it do anything
break;
}
}
@@ -836,7 +836,7 @@ int main(void)
case CMD_LEAVE_PROGMODE_ISP:
isLeave = 1;
- //* fall thru
+ //* fall through
case CMD_SET_PARAMETER:
case CMD_ENTER_PROGMODE_ISP:
diff --git a/Tools/ArduPPM/Libraries/PPM_Encoder_v3.h b/Tools/ArduPPM/Libraries/PPM_Encoder_v3.h
index 7efd0d7a20..ae692188f0 100644
--- a/Tools/ArduPPM/Libraries/PPM_Encoder_v3.h
+++ b/Tools/ArduPPM/Libraries/PPM_Encoder_v3.h
@@ -61,7 +61,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
// -------------------------------------------------------------
#define SWITCHOVER_CHANNEL_A 9 // Receiver 1 PPM channel to force receiver 2. Use 0 for no switchover channel
- // Must be choosed between 6 to 16. Preferabily from 9 to 16 so that APM can use
+ // Must be chosen between 6 to 16. Preferabily from 9 to 16 so that APM can use
// channels 1 to 8.
@@ -113,7 +113,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH1_VAL_CENTER TICKS_FOR_ONE_US * 1520
#define PPM_CH1_FORCE_VAL_MIN 1800
// PPM channel pre pulse lenght
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 400
// PPM frame sync symbol limits
@@ -136,7 +136,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH1_VAL_CENTER TICKS_FOR_ONE_US * 760
#define PPM_CH1_FORCE_VAL_MIN 900
// PPM channel pre pulse lenght
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 200
// PPM frame sync symbol limits
@@ -159,7 +159,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH1_VAL_CENTER TICKS_FOR_ONE_US * 1050
#define PPM_CH1_FORCE_VAL_MIN 1260
// PPM channel pre pulse lenght
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 400
// PPM frame sync symbol limits
@@ -195,7 +195,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH2_VAL_MAX TICKS_FOR_ONE_US * 2120
#define PPM_CH2_VAL_CENTER TICKS_FOR_ONE_US * 1520
// PPM channel pre pulse lenght
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 400
// PPM frame sync symbol limits
@@ -217,7 +217,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH2_VAL_MAX TICKS_FOR_ONE_US * 1060
#define PPM_CH2_VAL_CENTER TICKS_FOR_ONE_US * 760
// PPM channel pre pulse lenght
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 200
// PPM sync symbol limits
@@ -239,7 +239,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH2_VAL_MAX TICKS_FOR_ONE_US * 1350
#define PPM_CH2_VAL_CENTER TICKS_FOR_ONE_US * 1050
// PPM channel pre pulse lenght
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 400
// PPM sync symbol limits
@@ -618,9 +618,9 @@ ISR( SERVO_INT_VECTOR )
// PPM2 pulse start time
static uint16_t ppm2_start[ 16 ] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
- // PPM1 pulse lenght
+ // PPM1 pulse length
static uint16_t ppm1_width[ 16 ] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
- // PPM2 pulse lenght
+ // PPM2 pulse length
static uint16_t ppm2_width[ 16 ] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
// Reset PPM channels ( 0 = Sync Symbol )
@@ -692,9 +692,9 @@ ISR( SERVO_INT_VECTOR )
// Check if we've got a high level (raising edge, channel start or sync symbol end)
if( servo_pins & 1 )
{
// Check for pre pulse lenght
ppm1_prepulse_width = servo_time - ppm1_prepulse_start;
- if ( true ) //Todo optionnal: We could add a test here for channel pre pulse lenght check
+ if ( true ) //Todo optionnal: We could add a test here for channel pre pulse length check
{
//We have a valid pre pulse
if( ppm1_channel == channel_count_ch1 ) // Check for last channel
@@ -721,16 +721,16 @@ ISR( SERVO_INT_VECTOR )
// -----------------------------------------------------------------------------------------------------------------------
else // We've got a low level (falling edge, channel end or sync symbol start)
{
- ppm1_width[ ppm1_channel ] = servo_time - ppm1_start[ ppm1_channel ]; // Calculate channel pulse lenght, or sync symbol lenght
+ ppm1_width[ ppm1_channel ] = servo_time - ppm1_start[ ppm1_channel ]; // Calculate channel pulse length, or sync symbol length
if(sync_ch1 == true) // Are we synchronized ?
{
- // Check channel pulse lenght validity
- if( ppm1_width[ ppm1_channel ] > ( PPM_CH1_VAL_MAX - PPM_CH1_CHANNEL_PREPULSE_LENGHT ) ) || ( ppm1_width[ ppm1_channel ] < ( PPM_CH1_VAL_MIN - PPM_CH1_CHANNEL_PREPULSE_LENGHT ) ) // If we have a valid pulse lenght
+ // Check channel pulse length validity
+ if( ppm1_width[ ppm1_channel ] > ( PPM_CH1_VAL_MAX - PPM_CH1_CHANNEL_PREPULSE_LENGHT ) ) || ( ppm1_width[ ppm1_channel ] < ( PPM_CH1_VAL_MIN - PPM_CH1_CHANNEL_PREPULSE_LENGHT ) ) // If we have a valid pulse length
{
// Reset channel error flag
channel_error_ch1 = false;
}
- else // We do not have a valid channel lenght
+ else // We do not have a valid channel length
{
if( ppm1_width[ ppm1_channel ] > PPM_CH1_MIN_SYNC_LENGHT ) || ( ppm1_width[ ppm1_channel ] < PPM_CH1_MAX_SYNC_LENGHT ) //Check for sync symbol
{
@@ -791,9 +791,9 @@ ISR( SERVO_INT_VECTOR )
// Check if we've got a high level (raising edge, channel start or sync symbol end)
if( servo_pins & 2 )
{
// Check for pre pulse lenght
ppm2_prepulse_width = servo_time - ppm2_prepulse_start;
- if ( true ) //Todo optionnal: We could add a test here for channel pre pulse lenght check
+ if ( true ) //Todo optionnal: We could add a test here for channel pre pulse length check
{
//We have a valid pre pulse
if( ppm2_channel == channel_count_ch2 ) // Check for last channel
@@ -820,16 +820,16 @@ ISR( SERVO_INT_VECTOR )
// -----------------------------------------------------------------------------------------------------------------------
else // We've got a low level (falling edge, channel end or sync symbol start)
{
- ppm2_width[ ppm2_channel ] = servo_time - ppm2_start[ ppm2_channel ]; // Calculate channel pulse lenght, or sync symbol lenght
+ ppm2_width[ ppm2_channel ] = servo_time - ppm2_start[ ppm2_channel ]; // Calculate channel pulse length, or sync symbol length
if(sync_ch2 == true) // Are we synchronized ?
{
- // Check channel pulse lenght validity
- if( ppm2_width[ ppm2_channel ] > ( PPM_CH2_VAL_MAX - PPM_CH2_CHANNEL_PREPULSE_LENGHT ) ) || ( ppm2_width[ ppm2_channel ] < ( PPM_CH2_VAL_MIN - PPM_CH2_CHANNEL_PREPULSE_LENGHT ) ) // If we have a valid pulse lenght
+ // Check channel pulse length validity
+ if( ppm2_width[ ppm2_channel ] > ( PPM_CH2_VAL_MAX - PPM_CH2_CHANNEL_PREPULSE_LENGHT ) ) || ( ppm2_width[ ppm2_channel ] < ( PPM_CH2_VAL_MIN - PPM_CH2_CHANNEL_PREPULSE_LENGHT ) ) // If we have a valid pulse length
{
// Reset channel error flag
channel_error_ch2 = false;
}
- else // We do not have a valid channel lenght
+ else // We do not have a valid channel length
{
if( ppm2_width[ ppm2_channel ] > PPM_CH2_MIN_SYNC_LENGHT ) || ( ppm2_width[ ppm2_channel ] < PPM_CH2_MAX_SYNC_LENGHT ) //Check for sync symbol
{
@@ -113,7 +113,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH1_VAL_CENTER TICKS_FOR_ONE_US * 1520
#define PPM_CH1_FORCE_VAL_MIN 1800
-// PPM channel pre pulse lenght
+// PPM channel pre pulse length
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 400
// PPM frame sync symbol limits
@@ -136,7 +136,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH1_VAL_CENTER TICKS_FOR_ONE_US * 760
#define PPM_CH1_FORCE_VAL_MIN 900
-// PPM channel pre pulse lenght
+// PPM channel pre pulse length
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 200
// PPM frame sync symbol limits
@@ -159,7 +159,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH1_VAL_CENTER TICKS_FOR_ONE_US * 1050
#define PPM_CH1_FORCE_VAL_MIN 1260
-// PPM channel pre pulse lenght
+// PPM channel pre pulse length
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 400
// PPM frame sync symbol limits
@@ -195,7 +195,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH2_VAL_MAX TICKS_FOR_ONE_US * 2120
#define PPM_CH2_VAL_CENTER TICKS_FOR_ONE_US * 1520
-// PPM channel pre pulse lenght
+// PPM channel pre pulse length
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 400
// PPM frame sync symbol limits
@@ -217,7 +217,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH2_VAL_MAX TICKS_FOR_ONE_US * 1060
#define PPM_CH2_VAL_CENTER TICKS_FOR_ONE_US * 760
-// PPM channel pre pulse lenght
+// PPM channel pre pulse length
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 200
// PPM sync symbol limits
@@ -239,7 +239,7 @@ volatile uint8_t servo_input_mode = JUMPER_SELECT_MODE;
#define PPM_CH2_VAL_MAX TICKS_FOR_ONE_US * 1350
#define PPM_CH2_VAL_CENTER TICKS_FOR_ONE_US * 1050
-// PPM channel pre pulse lenght
+// PPM channel pre pulse length
#define PPM_CH1_CHANNEL_PREPULSE_LENGHT 400
// PPM sync symbol limits
@@ -692,9 +692,9 @@ ISR( SERVO_INT_VECTOR )
if( servo_pins & 1 )
{
- // Check for pre pulse lenght
+ // Check for pre pulse length
ppm1_prepulse_width = servo_time - ppm1_prepulse_start;
@@ -791,9 +791,9 @@ ISR( SERVO_INT_VECTOR )
if( servo_pins & 2 )
{
- // Check for pre pulse lenght
+ // Check for pre pulse length
ppm2_prepulse_width = servo_time - ppm2_prepulse_start;